@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: admin.py 11069 2018-05-21 10:18:52Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-05-21 18:18:52 +0800 (週一, 21 五月 2018) $
+# $Revision: 11069 $
 
 from django.contrib import admin
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
+from django.core.management import call_command
 from aldryn_newsblog.admin import ArticleAdmin
 from aldryn_newsblog.models import Article
 from djangocms_text_ckeditor.models import Text
@@ -32,7 +33,6 @@ class ArticleAdmin2(ArticleAdmin):
                 'is_published',
                 'is_featured',
                 'featured_image',
-                'lead_in', # display or not
             )
         }),
         (_('Meta Options'), {
@@ -62,6 +62,8 @@ class ArticleAdmin2(ArticleAdmin):
             placeholder=obj.content,
             language=obj.language_code,
             body=body, plugin_type='TextPlugin')
+
+        call_command('update_index', noinput=True)
         return super(ArticleAdmin2, self).response_add(
             request, obj, post_url_continue=None)
 
